# CyFES

## 介绍
这是一个使用Cython+CUDA+Python编写的高性能FES计算软件。

## 安装
### 源码安装
首先将本仓库clone到本地：
```bash
$ git clone https://gitee.com/dechin/cy-fes.git && cd cy-fes/
```
直接运行`setup.py`进行安装：
```bash
$ python3 setup.py install
```

## 测试
在本仓库的test路径下存放了一个测试用例，需要在本地先安装`pytest`：
```bash
$ python3 -m pip install pytest
```
然后直接在仓库的根目录下运行：
```bash
$ py.test
=========================== test session starts ===========================
platform linux -- Python 3.7.5, pytest-7.4.4, pluggy-1.2.0
rootdir: /home/cy-fes
collected 1 item                                                          

tests/test_path_fes.py .                                            [100%]

============================ 1 passed in 2.69s ============================
```
没有报错，则表示安装成功。或者也可以直接运行相关的测试文件：
```bash
$ python3 tests/test_path_fes.py 
[0.00892185 0.         0.09578881 0.01997518]
```
若输出为一个数组，则表示安装成功。

## 使用方法
在安装成功后，可以直接在Python脚本中调用：
```python
import numpy as np
from cyfes import PathFES
np.random.seed(0)

def test_path_fes():
    atoms = 4
    cvs = 10000
    crd = np.random.random((atoms, 3))
    cv = np.random.random((cvs, 3))
    bw = np.random.random(3)
    bias = np.random.random(cvs)-1

    fes = np.asarray(PathFES(crd, cv, bw, bias))
    print (fes)

if __name__ == '__main__':
    test_path_fes()
```
